@@ -16,7 +16,17 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
@@ -24,7 +34,8 @@ from google.api_core import retry as retries
 from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.shell_v1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -171,9 +182,9 @@ class CloudShellServiceAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, CloudShellServiceTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the cloud shell service client.
@@ -217,11 +228,11 @@ class CloudShellServiceAsyncClient:
 
     async def get_environment(
         self,
-        request: Union[cloudshell.GetEnvironmentRequest, dict] = None,
+        request: Optional[Union[cloudshell.GetEnvironmentRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> cloudshell.Environment:
         r"""Gets an environment. Returns NOT_FOUND if the environment does
@@ -254,7 +265,7 @@ class CloudShellServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.shell_v1.types.GetEnvironmentRequest, dict]):
+            request (Optional[Union[google.cloud.shell_v1.types.GetEnvironmentRequest, dict]]):
                 The request object. Request message for
                 [GetEnvironment][google.cloud.shell.v1.CloudShellService.GetEnvironment].
             name (:class:`str`):
@@ -337,10 +348,10 @@ class CloudShellServiceAsyncClient:
 
     async def start_environment(
         self,
-        request: Union[cloudshell.StartEnvironmentRequest, dict] = None,
+        request: Optional[Union[cloudshell.StartEnvironmentRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Starts an existing environment, allowing clients to
@@ -376,13 +387,13 @@ class CloudShellServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.shell_v1.types.StartEnvironmentRequest, dict]):
+            request (Optional[Union[google.cloud.shell_v1.types.StartEnvironmentRequest, dict]]):
                 The request object. Request message for
                 [StartEnvironment][google.cloud.shell.v1.CloudShellService.StartEnvironment].
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -438,10 +449,10 @@ class CloudShellServiceAsyncClient:
 
     async def authorize_environment(
         self,
-        request: Union[cloudshell.AuthorizeEnvironmentRequest, dict] = None,
+        request: Optional[Union[cloudshell.AuthorizeEnvironmentRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Sends OAuth credentials to a running environment on
@@ -474,13 +485,13 @@ class CloudShellServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.shell_v1.types.AuthorizeEnvironmentRequest, dict]):
+            request (Optional[Union[google.cloud.shell_v1.types.AuthorizeEnvironmentRequest, dict]]):
                 The request object. Request message for
                 [AuthorizeEnvironment][google.cloud.shell.v1.CloudShellService.AuthorizeEnvironment].
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -535,10 +546,10 @@ class CloudShellServiceAsyncClient:
 
     async def add_public_key(
         self,
-        request: Union[cloudshell.AddPublicKeyRequest, dict] = None,
+        request: Optional[Union[cloudshell.AddPublicKeyRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Adds a public SSH key to an environment, allowing clients with
@@ -570,13 +581,13 @@ class CloudShellServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.shell_v1.types.AddPublicKeyRequest, dict]):
+            request (Optional[Union[google.cloud.shell_v1.types.AddPublicKeyRequest, dict]]):
                 The request object. Request message for
                 [AddPublicKey][google.cloud.shell.v1.CloudShellService.AddPublicKey].
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -633,10 +644,10 @@ class CloudShellServiceAsyncClient:
 
     async def remove_public_key(
         self,
-        request: Union[cloudshell.RemovePublicKeyRequest, dict] = None,
+        request: Optional[Union[cloudshell.RemovePublicKeyRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Removes a public SSH key from an environment. Clients will no
@@ -668,13 +679,13 @@ class CloudShellServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.shell_v1.types.RemovePublicKeyRequest, dict]):
+            request (Optional[Union[google.cloud.shell_v1.types.RemovePublicKeyRequest, dict]]):
                 The request object. Request message for
                 [RemovePublicKey][google.cloud.shell.v1.CloudShellService.RemovePublicKey].
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -736,14 +747,9 @@ class CloudShellServiceAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-shell",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("CloudShellServiceAsyncClient",)
